m4-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[SCM] GNU M4 source repository branch, master, updated. cvs-readonly-60-


From: Eric Blake
Subject: [SCM] GNU M4 source repository branch, master, updated. cvs-readonly-60-g4af40c4
Date: Mon, 11 Feb 2008 21:16:26 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU M4 source repository".

http://git.sv.gnu.org/gitweb/?p=m4.git;a=commitdiff;h=4af40c4d6f65e3d311ef4643b6b3bdb9729a9db6

The branch, master has been updated
       via  4af40c4d6f65e3d311ef4643b6b3bdb9729a9db6 (commit)
       via  7a7a1413755c74b416295b13fe90eef3bffa7345 (commit)
       via  5e49a742b46299c471ad3d54faa487f073a51538 (commit)
      from  4f1f438e49632dbd5c5061d8992498acea8cf4b3 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 4af40c4d6f65e3d311ef4643b6b3bdb9729a9db6
Author: Eric Blake <address@hidden>
Date:   Mon Feb 11 07:14:20 2008 -0700

    Allow builtin text macros to specify number of arguments.
    
    * m4/m4module.h (struct m4_macro): Add argument limits to builtin
    text macros.
    * m4/module.c (install_macro_table): Allow text macros to warn on
    extra arguments.
    * modules/gnu.c (m4_macro_table): Update all clients.
    * modules/load.c (m4_macro_table): Likewise.
    * modules/mpeval.c (m4_macro_table): Likewise.
    * modules/perl.c (m4_macro_table): Likewise.
    * modules/shadow.c (m4_macro_table): Likewise.
    * modules/traditional.c (m4_macro_table): Likewise.
    * modules/modtest.c (m4_macro_table): Likewise.  Also add text
    macros, for testing this.
    * doc/m4.texinfo (Standard Modules): Update text, and enhance
    test.
    * tests/modules.at (modules: text): New test.
    
    Signed-off-by: Eric Blake <address@hidden>

commit 7a7a1413755c74b416295b13fe90eef3bffa7345
Author: Eric Blake <address@hidden>
Date:   Mon Feb 11 11:32:12 2008 -0700

    Fix regression in command line -D option, from 2006-08-25.
    
    * m4/m4private.h (m4_symbol_value_create): Delete fast accessor.
    * m4/m4module.h: Fix typo.
    * m4/symtab.c (m4_symbol_value_create): Prime the maximum number
    of arguments.
    * tests/macros.at (Command line define): Enhance test.
    * tests/others.at (nul character): Enhance test.
    * tests/null.m4: Likewise.
    * tests/null.out: Likewise.
    
    Signed-off-by: Eric Blake <address@hidden>

commit 5e49a742b46299c471ad3d54faa487f073a51538
Author: Eric Blake <address@hidden>
Date:   Mon Feb 11 11:19:18 2008 -0700

    Use gnulib's git-merge-changelog driver when available.
    
    * .gitattributes: Add merge attributes for ChangeLog.
    * bootstrap: Install driver, if not already present.
    
    Signed-off-by: Eric Blake <address@hidden>

-----------------------------------------------------------------------

Summary of changes:
 .gitattributes        |    1 +
 ChangeLog             |   35 ++++++++++++++++++++++++++++++++++-
 bootstrap             |   16 ++++++++++++++--
 doc/m4.texinfo        |   24 +++++++++++++++++++++---
 m4/m4module.h         |    5 ++++-
 m4/m4private.h        |    3 +--
 m4/module.c           |    7 ++++++-
 m4/symtab.c           |    4 +++-
 modules/gnu.c         |   14 +++++++-------
 modules/load.c        |    9 +++++----
 modules/modtest.c     |   12 +++++++-----
 modules/mpeval.c      |    9 +++++----
 modules/perl.c        |    6 +++---
 modules/shadow.c      |    9 +++++----
 modules/traditional.c |   14 +++++++-------
 tests/macros.at       |    9 +++++++++
 tests/modules.at      |   44 +++++++++++++++++++++++++++++++++++++++++++-
 tests/null.m4         |  Bin 3998 -> 6508 bytes
 tests/null.out        |  Bin 338 -> 400 bytes
 tests/others.at       |   10 ++++++++--
 20 files changed, 183 insertions(+), 48 deletions(-)

diff --git a/.gitattributes b/.gitattributes
index 3c0e9d5..a7c8702 100644
--- a/.gitattributes
+++ b/.gitattributes
@@ -1,2 +1,3 @@
 null.* diff merge
 iso8859.m4 diff merge
+ChangeLog merge=merge-changelog
diff --git a/ChangeLog b/ChangeLog
index 5341313..2554a45 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,36 @@
+2008-02-11  Eric Blake  <address@hidden>
+
+       Allow builtin text macros to specify number of arguments.
+       * m4/m4module.h (struct m4_macro): Add argument limits to builtin
+       text macros.
+       * m4/module.c (install_macro_table): Allow text macros to warn on
+       extra arguments.
+       * modules/gnu.c (m4_macro_table): Update all clients.
+       * modules/load.c (m4_macro_table): Likewise.
+       * modules/mpeval.c (m4_macro_table): Likewise.
+       * modules/perl.c (m4_macro_table): Likewise.
+       * modules/shadow.c (m4_macro_table): Likewise.
+       * modules/traditional.c (m4_macro_table): Likewise.
+       * modules/modtest.c (m4_macro_table): Likewise.  Also add text
+       macros, for testing this.
+       * doc/m4.texinfo (Standard Modules): Update text, and enhance
+       test.
+       * tests/modules.at (modules: text): New test.
+
+       Fix regression in command line -D option, from 2006-08-25.
+       * m4/m4private.h (m4_symbol_value_create): Delete fast accessor.
+       * m4/m4module.h: Fix typo.
+       * m4/symtab.c (m4_symbol_value_create): Prime the maximum number
+       of arguments.
+       * tests/macros.at (Command line define): Enhance test.
+       * tests/others.at (nul character): Enhance test.
+       * tests/null.m4: Likewise.
+       * tests/null.out: Likewise.
+
+       Use gnulib's git-merge-changelog driver when available.
+       * .gitattributes: Add merge attributes for ChangeLog.
+       * bootstrap: Install driver, if not already present.
+
 2008-02-06  Eric Blake  <address@hidden>
 
        Fix security hole introduced 2007-11-23.
@@ -41,7 +74,7 @@
        argument of a $@ at a time; but the penalties of this patch make
        it easier to manage $@ efficiently in future patches.
        Memory impact: noticeable penalty, due to larger struct and O(n)
-       to O(n^2) on unboxed recursion
+       to O(n^2) on unboxed recursion.
        Speed impact: noticeable penalty, due to more bookkeeping.
        * m4/m4private.h (struct m4__symbol_chain): Add comma and quotes
        fields.
diff --git a/bootstrap b/bootstrap
index a66eb03..fc29a2f 100755
--- a/bootstrap
+++ b/bootstrap
@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# bootstrap (GNU M4) version 2008-01-31
+# bootstrap (GNU M4) version 2008-02-11
 # Copyright (C) 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 # License GPLv3+: GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>
 # This is free software: you are free to change and redistribute it.
@@ -392,6 +392,19 @@ EOF
   cp $config_macro_dir/.cvsignore $config_macro_dir/.gitignore
 fi
 
+# See if we can use gnulib's git-merge-changelog merge driver.
+if test -d .git && (git --version) >/dev/null 2>/dev/null ; then
+  if git config merge.merge-changelog.driver >/dev/null ; then
+    :
+  elif (git-merge-changelog --version) >/dev/null 2>/dev/null ; then
+    func_echo "initializing git-merge-changelog driver"
+    git config merge.merge-changelog.name 'GNU-style ChangeLog merge driver'
+    git config merge.merge-changelog.driver 'git-merge-changelog %O %A %B'
+  else
+    func_echo "consider installing git-merge-changelog from gnulib"
+  fi
+fi
+
 ## ---------- ##
 ## Autopoint. ##
 ## ---------- ##
@@ -411,7 +424,6 @@ $AUTOPOINT --force
 func_echo "running: $LIBTOOLIZE --force --copy --install"
 ${LIBTOOLIZE} --force --copy --install
 
-
 ## ---------------------------- ##
 ## Find the gnulib module tree. ##
 ## ---------------------------- ##
diff --git a/doc/m4.texinfo b/doc/m4.texinfo
index 642c14e..357358f 100644
--- a/doc/m4.texinfo
+++ b/doc/m4.texinfo
@@ -5804,7 +5804,9 @@ refcount(`NoSuchModule')
 @acronym{GNU} @code{m4} ships with several bundled modules as standard.
 By convention, these modules define a text macro that can be tested
 with @code{ifdef} when they are loaded; only the @code{m4} module lacks
-this feature test macro.
+this feature test macro, since it is not permitted by @acronym{POSIX}.
+Each of the feature test macros are intended to be used without
+arguments.
 
 @table @code
 @item m4
@@ -5823,8 +5825,8 @@ module is loaded.
 @end deffn
 
 @deffn {Macro (gnu)} __m4_version__
-Expands to a quoted string containing the release version number of the
-running @acronym{GNU} @code{m4} executable.
+Expands to an unquoted string containing the release version number of
+the running @acronym{GNU} @code{m4} executable.
 @end deffn
 
 This module is always loaded, unless the @option{-G} command line
@@ -5871,6 +5873,9 @@ __gnu__-__traditional__
 @result{}-__traditional__
 ifdef(`__gnu__', `Extensions are active', `Minimal features')
 @result{}Extensions are active
+__gnu__(`ignored')
address@hidden:stdin:3: Warning: __gnu__: extra arguments ignored: 1 > 0
address@hidden
 @end example
 
 @comment options: -G
@@ -5882,6 +5887,19 @@ ifdef(`__gnu__', `Extensions are active', `Minimal 
features')
 @result{}Minimal features
 @end example
 
+Since the version string is unquoted and can potentially contain macro
+names (consider the beta release @samp{1.9b}, or the use of
address@hidden), the @code{__m4_version__} macro should generally
+be used via @code{defn} rather than directly invoked.
+
address@hidden This test is excluded from the testsuite since it depends on a
address@hidden texinfo macro; but builtin.at covers the same thing.
address@hidden ignore
address@hidden
+defn(`__m4_version__')
address@hidden@value{VERSION}
address@hidden example
+
 @node Text handling
 @chapter Macros for text handling
 
diff --git a/m4/m4private.h b/m4/m4private.h
index 28ac867..77590f3 100644
--- a/m4/m4private.h
+++ b/m4/m4private.h
@@ -330,8 +330,7 @@ extern void m4__push_arg_quote      (m4 *, m4_obstack *, 
m4_macro_args *,
 #  define m4_get_symbol_value(S)       ((S)->value)
 #  define m4_set_symbol_value(S, V)    ((S)->value = (V))
 
-#  define m4_symbol_value_create()     xzalloc (sizeof (m4_symbol_value))
-/* m4_symbol_value_delete is too complex for a simple macro.  */
+/* m4_symbol_value_{create,delete} are too complex for a simple macro.  */
 
 #  define m4_is_symbol_value_text(V)   ((V)->type == M4_SYMBOL_TEXT)
 #  define m4_is_symbol_value_func(V)   ((V)->type == M4_SYMBOL_FUNC)
diff --git a/m4/module.c b/m4/module.c
index 901a48f..7ef6ab3 100644
--- a/m4/module.c
+++ b/m4/module.c
@@ -1,6 +1,6 @@
 /* GNU m4 -- A simple macro processor
    Copyright (C) 1989, 1990, 1991, 1992, 1993, 1994, 1998, 1999, 2002, 2003,
-   2004, 2005, 2006, 2007 Free Software Foundation, Inc.
+   2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -195,9 +195,14 @@ install_macro_table (m4 *context, m4_module *module)
          m4_symbol_value *value = m4_symbol_value_create ();
          size_t len = strlen (mp->value);
 
+         /* Sanity check that builtins meet the required interface.  */
+         assert (mp->min_args <= mp->max_args);
+
          m4_set_symbol_value_text (value, xmemdup (mp->value, len + 1),
                                     len, 0);
          VALUE_MODULE (value) = module;
+         VALUE_MIN_ARGS (value) = mp->min_args;
+         VALUE_MAX_ARGS (value) = mp->max_args;
 
          m4_symbol_pushdef (M4SYMTAB, mp->name, value);
        }
diff --git a/m4/symtab.c b/m4/symtab.c
index 0d2055e..f302fe8 100644
--- a/m4/symtab.c
+++ b/m4/symtab.c
@@ -674,7 +674,9 @@ m4_get_symbol_traced (m4_symbol *symbol)
 m4_symbol_value *
 m4_symbol_value_create (void)
 {
-  return xzalloc (sizeof (m4_symbol_value));
+  m4_symbol_value *value = xzalloc (sizeof (m4_symbol_value));
+  VALUE_MAX_ARGS (value) = SIZE_MAX;
+  return value;
 }
 
 #undef m4_symbol_value_groks_macro
diff --git a/modules/gnu.c b/modules/gnu.c
index 1f6bf29..10fb0ac 100644
--- a/modules/gnu.c
+++ b/modules/gnu.c
@@ -85,20 +85,20 @@ m4_builtin m4_builtin_table[] =
 /* A table for mapping m4 symbol names to simple expansion text. */
 m4_macro m4_macro_table[] =
 {
-  /* name              text */
+  /* name              text    min     max */
 #if UNIX
-  { "__unix__",                "" },
+  { "__unix__",                "",     0,      0 },
 #elif W32_NATIVE
-  { "__windows__",     "" },
+  { "__windows__",     "",     0,      0 },
 #elif OS2
-  { "__os2__",         "" },
+  { "__os2__",         "",     0,      0 },
 #else
 # warning Platform macro not provided
 #endif
-  { "__gnu__",         "" },
-  { "__m4_version__",  VERSION/**/TIMESTAMP },
+  { "__gnu__",         "",     0,      0 },
+  { "__m4_version__",  VERSION/**/TIMESTAMP, 0, 0 },
 
-  { NULL, NULL },
+  { NULL,              NULL,   0,      0 },
 };
 
 
diff --git a/modules/load.c b/modules/load.c
index 4ee1cc6..5ea7242 100644
--- a/modules/load.c
+++ b/modules/load.c
@@ -1,5 +1,6 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 2000, 2005, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2005, 2006, 2007, 2008 Free Software
+   Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -65,9 +66,9 @@ m4_builtin m4_builtin_table[] =
 /* A table for mapping m4 symbol names to simple expansion text. */
 m4_macro m4_macro_table[] =
 {
-  /* name              text */
-  { "__load__",                "" },
-  { NULL,              NULL },
+  /* name              text    min     max */
+  { "__load__",                "",     0,      0 },
+  { NULL,              NULL,   0,      0 },
 };
 
 
diff --git a/modules/modtest.c b/modules/modtest.c
index 022a2ef..f2d39ea 100644
--- a/modules/modtest.c
+++ b/modules/modtest.c
@@ -1,6 +1,6 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 1999, 2000, 2001, 2003, 2004, 2006, 2007 Free Software
-   Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2003, 2004, 2006, 2007, 2008 Free
+   Software Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -61,9 +61,11 @@ m4_builtin m4_builtin_table[] =
 
 m4_macro m4_macro_table[] =
 {
-  /* name              text */
-  { "__test__",                "`modtest'" },
-  { NULL,              NULL },
+  /* name              text            min     max */
+  { "__test__",                "`modtest'",    0,      0 },
+  { "onearg",          "$1",           1,      1 },
+  { "manyargs",                "$@",           0,      SIZE_MAX },
+  { NULL,              NULL,           0,      0 },
 };
 
 
diff --git a/modules/mpeval.c b/modules/mpeval.c
index e70eb09..ab9a040 100644
--- a/modules/mpeval.c
+++ b/modules/mpeval.c
@@ -1,5 +1,6 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 2000, 2001, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2001, 2006, 2007, 2008 Free Software
+   Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -123,9 +124,9 @@ m4_builtin m4_builtin_table[] =
 /* A table for mapping m4 symbol names to simple expansion text. */
 m4_macro m4_macro_table[] =
 {
-  /* name              text */
-  { "__mpeval__",      "" },
-  { NULL,              NULL },
+  /* name              text    min     max */
+  { "__mpeval__",      "",     0,      0 },
+  { NULL,              NULL,   0,      0 },
 };
 
 
diff --git a/modules/perl.c b/modules/perl.c
index 46cf2cd..61db803 100644
--- a/modules/perl.c
+++ b/modules/perl.c
@@ -64,9 +64,9 @@ m4_builtin m4_builtin_table[] =
 /* A table for mapping m4 symbol names to simple expansion text. */
 m4_macro m4_macro_table[] =
 {
-  /* name                      text */
-  { "__perleval__",            "" },
-  { NULL, NULL },
+  /* name              text    min     max */
+  { "__perleval__",    "",     0,      0 },
+  { NULL,              NULL,   0,      0 },
 };
 
 
diff --git a/modules/shadow.c b/modules/shadow.c
index 3698b4f..1a15798 100644
--- a/modules/shadow.c
+++ b/modules/shadow.c
@@ -1,5 +1,6 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 1999, 2000, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2006, 2007, 2008 Free Software
+   Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -58,9 +59,9 @@ m4_builtin m4_builtin_table[] =
 
 m4_macro m4_macro_table[] =
 {
-  /* name              text */
-  { "__test__",                "`shadow'" },
-  { NULL, NULL },
+  /* name              text            min     max */
+  { "__test__",                "`shadow'",     0,      0 },
+  { NULL,              NULL,           0,      0 },
 };
 
 
diff --git a/modules/traditional.c b/modules/traditional.c
index 9fc2e81..13a112d 100644
--- a/modules/traditional.c
+++ b/modules/traditional.c
@@ -1,5 +1,5 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 2000, 2006, 2007 Free Software Foundation, Inc.
+   Copyright (C) 2000, 2006, 2007, 2008 Free Software Foundation, Inc.
 
    This file is part of GNU M4.
 
@@ -33,16 +33,16 @@
 /* A table for mapping m4 symbol names to simple expansion text. */
 m4_macro m4_macro_table[] =
 {
-  /* name              text */
+  /* name              text    min     max */
 #if UNIX
-  { "unix",            "" },
+  { "unix",            "",     0,      0 },
 #elif W32_NATIVE
-  { "windows",         "" },
+  { "windows",         "",     0,      0 },
 #elif OS2
-  { "os2",             "" },
+  { "os2",             "",     0,      0 },
 #else
 # warning Platform macro not provided
 #endif
-  { "__traditional__", "" },
-  { NULL,              NULL },
+  { "__traditional__", "",     0,      0 },
+  { NULL,              NULL,   0,      0 },
 };
diff --git a/tests/macros.at b/tests/macros.at
index 3d74356..d0dd7e1 100644
--- a/tests/macros.at
+++ b/tests/macros.at
@@ -140,6 +140,15 @@ AT_CHECK_M4([-Ufoo in -Dfoo=bar in], [0], [[foo
 bar
 ]])
 
+dnl Test macro arguments defined via -D
+AT_DATA([in], [[-foo-foo(1)-foo(1,2)-
+-bar-bar(1)-bar(1,2)-
+]])
+AT_CHECK_M4([-Dfoo -Dbar='$@' in], [0],
+[[----
+--1-1,2-
+]])
+
 AT_CLEANUP
 
 
diff --git a/tests/modules.at b/tests/modules.at
index 86f1388..0d81848 100644
--- a/tests/modules.at
+++ b/tests/modules.at
@@ -1,5 +1,5 @@
 # Hand crafted tests for GNU M4.                               -*- Autotest -*-
-# Copyright (C) 2001, 2006, 2007 Free Software Foundation, Inc.
+# Copyright (C) 2001, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 # This file is part of GNU M4.
 #
@@ -422,6 +422,48 @@ AT_CLEANUP
 
 
 
+## ------------------- ##
+## text module symbols ##
+## ------------------- ##
+
+# Support text macros with requested numbers of parameters.
+
+AT_SETUP([modules: text])
+AT_CHECK_DYNAMIC_MODULE
+
+AT_DATA([input.m4],
+[[__test__
+__test__(1)
+__test__(1,2)
+onearg
+onearg(1)
+onearg(1,2)
+manyargs
+manyargs(1)
+manyargs(1,2)
+]])
+
+AT_CHECK_M4([-M "$abs_builddir" -m modtest input.m4], [0],
+[[modtest
+modtest
+modtest
+
+1
+1
+
+1
+1,2
+]], [[Test module loaded.
+m4:input.m4:2: Warning: __test__: extra arguments ignored: 1 > 0
+m4:input.m4:3: Warning: __test__: extra arguments ignored: 2 > 0
+m4:input.m4:4: Warning: onearg: too few arguments: 0 < 1
+m4:input.m4:6: Warning: onearg: extra arguments ignored: 2 > 1
+Test module unloaded.
+]])
+
+AT_CLEANUP
+
+
 ## -------------------- ##
 ## trace module symbols ##
 ## -------------------- ##
diff --git a/tests/null.m4 b/tests/null.m4
index e6e1816..2fa38dd 100644
Binary files a/tests/null.m4 and b/tests/null.m4 differ
diff --git a/tests/null.out b/tests/null.out
index 6e8a114..c42e03c 100644
Binary files a/tests/null.out and b/tests/null.out differ
diff --git a/tests/others.at b/tests/others.at
index bb6254a..0b58c29 100644
--- a/tests/others.at
+++ b/tests/others.at
@@ -1,5 +1,5 @@
 # Hand crafted tests for GNU M4.                               -*- Autotest -*-
-# Copyright (C) 2001, 2006, 2007 Free Software Foundation, Inc.
+# Copyright (C) 2001, 2006, 2007, 2008 Free Software Foundation, Inc.
 
 # This file is part of GNU M4.
 #
@@ -321,7 +321,13 @@ AT_SETUP([nul character])
 cp "$abs_srcdir/null.out" expout
 cp "$abs_srcdir/null.err" experr
 
-AT_CHECK_M4(["$abs_srcdir/null.m4"], [0], [expout], [experr])
+dnl all but m4exit
+AT_CHECK_M4([-Dm4exit "$abs_srcdir/null.m4"], [0], [expout], [experr])
+
+dnl just m4exit
+AT_CHECK_M4(["$abs_srcdir/null.m4"], [2],
+[[# This file tests m4 behavior on NUL bytes.
+]])
 
 AT_CLEANUP
 


hooks/post-receive
diff --git a/m4/m4module.h b/m4/m4module.h
index bdb31a3..a807e70 100644
--- a/m4/m4module.h
+++ b/m4/m4module.h
@@ -67,7 +67,7 @@ struct m4_builtin
   const char *     name;       /* name found by builtin, printed by dumpdef */
   int              flags;      /* bitwise OR of M4_BUILTIN_* bits */
   size_t           min_args;   /* 0-based minimum number of arguments */
   /* max arguments, UINT_MAX if unlimited; must be >= min_args */
   size_t           max_args;
 };
 
@@ -75,6 +75,9 @@ struct m4_macro
 {
   const char *name;
   const char *value;
+  size_t      min_args; /* 0-based minimum number of arguments */
+  /* max arguments, SIZE_MAX if unlimited; must be >= min_args */
+  size_t      max_args;
 };
 
 /* Describe a pair of strings, such as begin and end quotes.  */
@@ -67,7 +67,7 @@ struct m4_builtin
   int              flags;      /* bitwise OR of M4_BUILTIN_* bits */
   size_t           min_args;   /* 0-based minimum number of arguments */
-  /* max arguments, UINT_MAX if unlimited; must be >= min_args */
+  /* max arguments, SIZE_MAX if unlimited; must be >= min_args */
   size_t           max_args;
 };
--
GNU M4 source repository




reply via email to

[Prev in Thread] Current Thread [Next in Thread]